@@ -236,28 +236,55 @@ class Cyrating(object):
     filter = {'where': json.dumps({'company': company['_id']})}
     company_tags = self.findall(TAGS_ENDPOINT, 1, filter)
     tags = dict()
+    domains_map = dict()
+
+    enable_entities = False
+    entities_map = dict()
+    if company['_id'] == self.__current_client__['company_id']:
+      enable_entities = True
+      companies_id = self.__current_client__['entities_id'] or []
+      filter = {'where': json.dumps({'_id': {'$in': companies_id}})}
+      entities = self.findall(COMPANY_ENDPOINT, 1, filter)
+      filter = {'where': json.dumps({'company': {'$in': companies_id}})}
+      entities_assets = self.findall(ASSETS_ENDPOINT, 1, filter)
+
+      for entity in entities:
+        assets = next(assets for assets in entities_assets if assets['company'] == entity['_id'])
+        domains = [node['label'] for node in assets['nodes'] if node['type'] == 'domain']
+        for domainname in domains:
+          if domainname not in entities_map:
+            entities_map[domainname] = []
+          entities_map[domainname].append(entity['name'])
+
     if company_tags:
       for item in company_tags:
         tags[item['domainname']] = item['tags'] if 'tags' in item else []
+        domains_map[item['domainname']] = item['domainname']
     assets = self.assets(company)
 
     domains = [node['label'] for node in assets['nodes'] if node['type'] == 'domain']
 
     res = dict()
     for node in assets['nodes']:
-      res[node['label']] = {'type': node['type'], 'tags': [], '_updated': False}
+      res[node['label']] = {'type': node['type'], 'tags': [], 'domains': [], 'entities': [], '_updated': False}
       if node['type'] == 'domain':
         res[node['label']]['tags'] = list(set(tags[node['label']] if node['label'] in tags else []))
+        res[node['label']]['domains'] = [domains_map[node['label']]]
+        res[node['label']]['entities'] = entities_map[node['label']] if enable_entities and node['label'] in entities_map else []
         res[node['label']]['_updated'] = True
 
     for link in assets['links']:
       if link['source'] in domains:
         res[link['target']]['tags'] = list(set(res[link['source']]['tags'] + res[link['target']]['tags']))
+        res[link['target']]['domains'] = list(set(res[link['source']]['domains'] + res[link['target']]['domains']))
+        res[link['target']]['entities'] = list(set(res[link['source']]['entities'] + res[link['target']]['entities']))
         res[link['target']]['_updated'] = True
 
     for link in assets['links']:
       if res[link['target']]['_updated'] is False:
         res[link['target']]['tags'] = list(set(res[link['source']]['tags'] + res[link['target']]['tags']))
+        res[link['target']]['domains'] = list(set(res[link['source']]['domains'] + res[link['target']]['domains']))
+        res[link['target']]['entities'] = list(set(res[link['source']]['entities'] + res[link['target']]['entities']))
         res[link['target']]['_updated'] = True
 
     return res
@@ -272,11 +299,15 @@ class Cyrating(object):
         for source in event['sources']:
           item = {
               'name': event['name'],
-              'url': event['url'] if 'url' in event else None,
               'type': event['type'],
               'occurences': source['occurences'],
-              'BL-TAG': source['name'],
-              'tags': assets[event['name']] if assets else None
+              'source': {
+                  'tag': source['name'],
+                  'source_url': event['url'] if 'url' in event else None
+              },
+              'tags': assets[event['name']]['tags'] if assets else None,
+              'domains': assets[event['name']]['domains'] if assets else None,
+              'entities': assets[event['name']]['entities'] if assets and 'entities' in assets[event['name']] else None,
           }
           res.append(item)
 
